"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_link_error_1 = require("apollo-link-error");
const apollo_link_http_1 = require("apollo-link-http");
const cross_fetch_1 = __importDefault(require("cross-fetch"));
const debug_1 = __importDefault(require("debug"));
const fs_1 = __importDefault(require("fs"));
const graphql_1 = require("graphql");
const graphql_binding_1 = require("graphql-binding");
exports.Binding = graphql_binding_1.Binding;
const graphql_tools_1 = require("graphql-tools");
const path_1 = __importDefault(require("path"));
const debug = debug_1.default('tcg:binding');
class Link extends apollo_link_http_1.HttpLink {
    constructor(uri, options) {
        const headers = { ...options };
        if (headers.token) {
            headers.Authorization = `Bearer ${headers.token}`;
            delete headers.token;
        }
        debug('headers', headers);
        super({
            fetch: cross_fetch_1.default,
            headers,
            uri
        });
    }
}
exports.Link = Link;
class RemoteBinding extends graphql_binding_1.Binding {
    constructor(httpLink, typeDefs) {
        // Workaround for issue with graphql-tools
        // See https://github.com/graphql-binding/graphql-binding/issues/173#issuecomment-446366548
        const errorLink = apollo_link_error_1.onError((args) => {
            if (args.graphQLErrors && args.graphQLErrors.length === 1) {
                args.response.errors = args.graphQLErrors.concat(new graphql_1.GraphQLError(''));
            }
        });
        const schema = graphql_tools_1.makeRemoteExecutableSchema({
            link: errorLink.concat(httpLink),
            schema: typeDefs
        });
        // debug('schema', JSON.stringify(schema));
        super({ schema });
    }
}
exports.RemoteBinding = RemoteBinding;
async function getRemoteBinding(endpoint, options) {
    if (!endpoint) {
        throw new Error('getRemoteBinding: endpoint is required');
    }
    debug('getRemoteBinding', endpoint, options);
    const link = new Link(endpoint, options);
    const introspectionResult = await graphql_tools_1.introspectSchema(link);
    // debug('introspectionResult', JSON.stringify(introspectionResult));
    return new RemoteBinding(link, graphql_1.printSchema(introspectionResult));
}
exports.getRemoteBinding = getRemoteBinding;
async function generateBindingFile(inputSchemaPathGraphQL, outputBindingFile) {
    debug('generateBindingFile:start');
    const sdl = fs_1.default.readFileSync(path_1.default.resolve(inputSchemaPathGraphQL), 'utf-8');
    const schema = graphql_1.buildSchema(sdl);
    const generatorOptions = {
        inputSchemaPath: path_1.default.resolve(inputSchemaPathGraphQL.replace('.graphql', '.ts')),
        isDefaultExport: true,
        outputBindingPath: path_1.default.resolve(outputBindingFile),
        schema
    };
    const generatorInstance = new graphql_binding_1.TypescriptGenerator(generatorOptions);
    const code = generatorInstance.render();
    const x = fs_1.default.writeFileSync(outputBindingFile, code);
    debug('generateBindingFile:end');
    return x;
}
exports.generateBindingFile = generateBindingFile;
