"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const graphql_1 = require("graphql");
const utils_2 = require("../../core/code-generator/utils");
function entityToResolver(entity) {
    const fields = [];
    const imports = [];
    entity.columns
        .filter((column) => !column.relationMetadata)
        .forEach((column) => {
        const { tsType } = utils_1.columnToTypes(column);
        const graphQLDataType = utils_1.columnTypeToGraphQLDataType(column);
        if (column.enum && !imports.includes(tsType)) {
            imports.push(tsType);
        }
        fields.push({
            name: column.propertyName,
            gclType: graphQLDataType,
            tsType,
            required: column.isNullable
        });
    });
    entity.relations.forEach((relation) => {
        const { graphqlType } = utils_1.relationToTypes(relation);
        const graphQLDataType = utils_1.relationTypeToGraphQLDataType(relation);
        if (!relation.inverseEntityMetadata || graphqlType.constructor !== graphql_1.GraphQLObjectType)
            return;
        switch (relation.relationType) {
            case 'many-to-one':
            case 'one-to-one':
                fields.push({
                    name: relation.propertyName,
                    relation: relation.relationType,
                    gclType: graphQLDataType,
                    tsType: graphqlType.name,
                    required: relation.isNullable,
                    relClass: relation.inverseEntityMetadata.name,
                    relField: relation.inverseSidePropertyPath
                });
                break;
            case 'one-to-many':
            case 'many-to-many':
                if (!imports.includes(`${graphqlType.name}Connection`)) {
                    imports.push(`${graphqlType.name}Connection`);
                }
                fields.push({
                    name: relation.propertyName,
                    relation: relation.relationType,
                    gclType: graphQLDataType,
                    tsType: graphqlType.name,
                    required: relation.isNullable,
                    relClass: graphqlType.name,
                    relField: relation.inverseSidePropertyPath
                });
                break;
        }
    });
    return utils_2.codeGeneratorUtil({
        pathToTemplate: `${__dirname}/../../cli/templates/resolver.ts.ejs`,
        fields,
        className: entity.name
    });
}
exports.entityToResolver = entityToResolver;
