"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const graphql_1 = require("graphql");
function entityToType(entity) {
    let fieldTemplates = ``;
    const imports = [];
    entity.columns
        .filter((column) => !column.relationMetadata)
        .forEach((column) => {
        const { tsType } = utils_1.columnToTypes(column);
        const graphQLDataType = utils_1.columnTypeToGraphQLDataType(column);
        const nullable = column.isNullable ? '{ nullable: true }' : '';
        const tsRequired = column.isNullable ? '?' : '!';
        if (column.enum && !imports.includes(tsType)) {
            imports.push(tsType);
        }
        fieldTemplates += `
        @FieldGraphQL(() => ${graphQLDataType},${nullable})
        ${column.propertyName}${tsRequired}: ${tsType};
      `;
    });
    entity.relations.forEach((relation) => {
        const { tsType, graphqlType } = utils_1.relationToTypes(relation);
        if (!relation.inverseEntityMetadata || graphqlType.constructor !== graphql_1.GraphQLObjectType)
            return;
        const nullable = relation.isNullable ? '{ nullable: true }' : '';
        const tsRequired = relation.isNullable ? '?' : '!';
        switch (relation.relationType) {
            case 'many-to-one':
            case 'one-to-one':
                if (!imports.includes(`${graphqlType.name}`)) {
                    imports.push(`${graphqlType.name}`);
                }
                fieldTemplates += `
      @FieldGraphQL(() => ${graphqlType.name},${nullable})
      ${relation.propertyName}${tsRequired}: ${tsType};
      `;
                break;
            case 'one-to-many':
            case 'many-to-many':
                if (!imports.includes(`${graphqlType.name}Connection`)) {
                    imports.push(`${graphqlType.name}Connection`);
                }
                fieldTemplates += `
      @FieldGraphQL(() => ${graphqlType.name}Connection)
      ${relation.propertyName}${tsRequired}: ${graphqlType.name}Connection;
      `;
                break;
        }
    });
    return `
  import 'reflect-metadata';
  import { ArgsType, Field as FieldGraphQL, Float, GraphQLISODateTime,
               ID, InputType,
               ObjectType, registerEnumType } from 'type-graphql';
  import { GraphQLJSONObject, IDType, ConnectionArgs,
           GraphQLBoolean, GraphQLFloat, GraphQLID,
           GraphQLInt, GraphQLString, ${imports.join(',')} } from '..';
  @ObjectType()
  export class ${entity.name} {
  ${fieldTemplates}
  }
  `;
}
exports.entityToType = entityToType;
