"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const graphql_1 = require("graphql");
const type_graphql_1 = require("type-graphql");
function entityToUpdateInputImporter(entity) {
    return `
    import {${entity.name}UpdateInput} from './input/update/${entity.name}UpdateInput';
    export {${entity.name}UpdateInput} from './input/update/${entity.name}UpdateInput';
  `;
}
exports.entityToUpdateInputImporter = entityToUpdateInputImporter;
function entityToWhereScalarInputImporter(entity) {
    return `
    import {${entity.name}ScalarWhereInput} from './input/update/${entity.name}ScalarWhereInput';
    export {${entity.name}ScalarWhereInput} from './input/update/${entity.name}ScalarWhereInput';
  `;
}
exports.entityToWhereScalarInputImporter = entityToWhereScalarInputImporter;
function entityToUpdateInputDataImporter(entity) {
    return `
    import {${entity.name}UpdateManyDataInput} from './input/update/${entity.name}UpdateManyDataInput';
    export {${entity.name}UpdateManyDataInput} from './input/update/${entity.name}UpdateManyDataInput';
  `;
}
exports.entityToUpdateInputDataImporter = entityToUpdateInputDataImporter;
function entityToUpdateManyWithWhereNestedInputImporter(entity) {
    return `
    import {${entity.name}UpdateManyWithWhereNestedInput} from './input/update/${entity.name}UpdateManyWithWhereNestedInput';
    export {${entity.name}UpdateManyWithWhereNestedInput} from './input/update/${entity.name}UpdateManyWithWhereNestedInput';
  `;
}
exports.entityToUpdateManyWithWhereNestedInputImporter = entityToUpdateManyWithWhereNestedInputImporter;
function entityToWhereScalarInput(entity) {
    let fieldTemplates = `
        @FieldGraphQL(() => [${entity.name}ScalarWhereInput],{nullable:true})
        AND?: ${entity.name}ScalarWhereInput[];
        @FieldGraphQL(() => [${entity.name}ScalarWhereInput],{nullable:true})
        OR?: ${entity.name}ScalarWhereInput[];
        @FieldGraphQL(() => [${entity.name}ScalarWhereInput],{nullable:true})
        NOT?: ${entity.name}ScalarWhereInput[];`;
    const enumImports = [];
    entity.columns
        .filter((column) => !column.relationMetadata)
        .forEach((column) => {
        const { graphqlType, tsType } = utils_1.columnToTypes(column);
        const graphQLDataType = utils_1.columnTypeToGraphQLDataType(column);
        if (column.enum && !enumImports.includes(tsType)) {
            enumImports.push(tsType);
        }
        switch (graphqlType) {
            case graphql_1.GraphQLID:
            case graphql_1.GraphQLString:
                fieldTemplates += `
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_not?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_gt?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_gte?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_lt?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_lte?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_contains?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_not_contains?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_starts_with?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_not_starts_with?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_ends_with?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_not_ends_with?: ${tsType};
        @FieldGraphQL(() => [${graphQLDataType}],{nullable:true})
        ${column.propertyName}_in?: ${tsType}[];
        @FieldGraphQL(() => [${graphQLDataType}],{nullable:true})
        ${column.propertyName}_not_in?: ${tsType}[];`;
                break;
            case graphql_1.GraphQLInt:
            case graphql_1.GraphQLFloat:
            case type_graphql_1.GraphQLISODateTime:
                fieldTemplates += `
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_not?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_gt?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_gte?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_lt?: ${tsType};
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}_lte?: ${tsType};
        @FieldGraphQL(() => [${graphQLDataType}],{nullable:true})
        ${column.propertyName}_in?: ${tsType}[];
        @FieldGraphQL(() => [${graphQLDataType}],{nullable:true})
        ${column.propertyName}_not_in?: ${tsType}[];`;
                break;
            default:
                fieldTemplates += `
          @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
          ${column.propertyName}?: ${tsType};
          @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
          ${column.propertyName}_not?: ${tsType};
          @FieldGraphQL(() => [${graphQLDataType}],{nullable:true})
          ${column.propertyName}_in?: ${tsType}[];
          @FieldGraphQL(() => [${graphQLDataType}],{nullable:true})
          ${column.propertyName}_not_in?: ${tsType}[];`;
                break;
        }
    });
    return `
  import 'reflect-metadata';
  import { ArgsType, Field as FieldGraphQL, Float, GraphQLISODateTime,
               ID, InputType,
               ObjectType, registerEnumType } from 'type-graphql';
  import { GraphQLJSONObject, IDType, ConnectionArgs,
           GraphQLBoolean, GraphQLFloat, GraphQLID,
           GraphQLInt, GraphQLString, ${enumImports.join(', ')} } from '../..';
  @InputType()
  export class ${entity.name}ScalarWhereInput {
  ${fieldTemplates}
  }
  `;
}
exports.entityToWhereScalarInput = entityToWhereScalarInput;
function entityToUpdateInputsImporter(entities) {
    const updateInputsNames = [];
    entities.forEach((entity) => {
        entity.relations.forEach((relation) => {
            const { graphqlType } = utils_1.relationToTypes(relation);
            if (!relation.inverseEntityMetadata || graphqlType.constructor !== graphql_1.GraphQLObjectType)
                return;
            const { inverseSidePropertyPath } = relation;
            const isInverse = Boolean(relation.inverseEntityMetadata.relations.find(inverseRelation => inverseRelation.propertyName === inverseSidePropertyPath));
            const inverseSidePropertyPathCapitalized = inverseSidePropertyPath.charAt(0).toUpperCase() + inverseSidePropertyPath.slice(1);
            const inputName = (prefix) => `${graphqlType.name}Update${prefix}${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`;
            const _updateInputNameWithWhere = (prefix, postfix) => `${graphqlType.name}Update${prefix}WithWhere${postfix}${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`;
            const updateInputName = inputName('');
            const updateInputNameUnique = _updateInputNameWithWhere('', 'Unique');
            const updateInputOneName = inputName('One');
            const updateInputManyName = inputName('Many');
            if (!updateInputsNames.includes(updateInputName) && isInverse) {
                updateInputsNames.push(updateInputName);
            }
            switch (relation.relationType) {
                case 'many-to-one':
                case 'one-to-one':
                    if (updateInputsNames.includes(updateInputOneName))
                        break;
                    updateInputsNames.push(updateInputOneName);
                    break;
                case 'one-to-many':
                case 'many-to-many':
                    if (!updateInputsNames.includes(updateInputManyName)) {
                        updateInputsNames.push(updateInputManyName);
                    }
                    if (!updateInputsNames.includes(updateInputNameUnique)) {
                        updateInputsNames.push(updateInputNameUnique);
                    }
                    break;
            }
        });
    });
    return updateInputsNames.reduce((prev, next) => `
     ${prev}
     import {${next}} from './input/update/${next}';
     export {${next}} from './input/update/${next}';
    `, '');
}
exports.entityToUpdateInputsImporter = entityToUpdateInputsImporter;
function entityToUpdateInput(entity) {
    let fieldTemplates = '';
    const imports = [];
    const enumImports = [];
    entity.columns
        .filter((column) => !column.relationMetadata &&
        !column.isPrimary &&
        !column.isCreateDate &&
        !column.isGenerated &&
        !column.isUpdateDate &&
        !column.isVersion)
        .forEach((column) => {
        const graphQLDataType = utils_1.columnTypeToGraphQLDataType(column);
        const tsType = utils_1.columnToTypeScriptType(column);
        if (column.enum && !enumImports.includes(tsType)) {
            enumImports.push(tsType);
        }
        fieldTemplates += `
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}?: ${tsType};
      `;
    });
    entity.relations.forEach((relation) => {
        const { graphqlType } = utils_1.relationToTypes(relation);
        if (!relation.inverseEntityMetadata || graphqlType.constructor !== graphql_1.GraphQLObjectType)
            return;
        const { propertyName, inverseSidePropertyPath } = relation;
        const isInverse = Boolean(relation.inverseEntityMetadata.relations.find(inverseRelation => inverseRelation.propertyName === inverseSidePropertyPath));
        const inverseSidePropertyPathCapitalized = inverseSidePropertyPath.charAt(0).toUpperCase() + inverseSidePropertyPath.slice(1);
        const nullable = '{nullable:true}';
        const tsRequired = '?';
        switch (relation.relationType) {
            case 'many-to-one':
            case 'one-to-one':
                if (!imports.includes(`${graphqlType.name}UpdateOne${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`)) {
                    imports.push(`${graphqlType.name}UpdateOne${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`);
                }
                fieldTemplates += `
      @FieldGraphQL(() => ${graphqlType.name}UpdateOne${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input,${nullable})
      ${propertyName}${tsRequired}: ${graphqlType.name}UpdateOne${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input;
      `;
                break;
            case 'one-to-many':
            case 'many-to-many':
                if (!imports.includes(`${graphqlType.name}UpdateMany${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`)) {
                    imports.push(`${graphqlType.name}UpdateMany${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`);
                }
                fieldTemplates += `
      @FieldGraphQL(() => ${graphqlType.name}UpdateMany${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input,${nullable})
      ${propertyName}${tsRequired}: ${graphqlType.name}UpdateMany${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input;
      `;
                break;
        }
    });
    return `
    import 'reflect-metadata';
    import { ArgsType, Field as FieldGraphQL, Float, GraphQLISODateTime,
               ID, InputType,
               ObjectType, registerEnumType } from 'type-graphql';
    import { GraphQLJSONObject,
             IDType, ConnectionArgs, PageInfo,
             GraphQLBoolean, GraphQLFloat, GraphQLID,
             GraphQLInt, GraphQLString, ${enumImports.join(', ')} } from '../..';
    ${imports.length
        ? `
    import { ${imports.join(', ')} } from '../..';
    `
        : ''}
    @InputType()
    export class ${entity.name}UpdateInput {
      ${fieldTemplates}
    }
  `;
}
exports.entityToUpdateInput = entityToUpdateInput;
function entityToUpdateDataInput(entity) {
    let fieldTemplates = '';
    const enumImports = [];
    entity.columns
        .filter((column) => !column.relationMetadata &&
        !column.isPrimary &&
        !column.isCreateDate &&
        !column.isGenerated &&
        !column.isUpdateDate &&
        !column.isVersion)
        .forEach((column) => {
        const graphQLDataType = utils_1.columnTypeToGraphQLDataType(column);
        const tsType = utils_1.columnToTypeScriptType(column);
        if (column.enum && !enumImports.includes(tsType)) {
            enumImports.push(tsType);
        }
        fieldTemplates += `
        @FieldGraphQL(() => ${graphQLDataType},{nullable:true})
        ${column.propertyName}?: ${tsType};
      `;
    });
    return `
    import 'reflect-metadata';
    import { ArgsType, Field as FieldGraphQL, Float, GraphQLISODateTime,
               ID, InputType,
               ObjectType, registerEnumType } from 'type-graphql';
    import { GraphQLJSONObject,
             IDType, ConnectionArgs, PageInfo,
             GraphQLBoolean, GraphQLFloat, GraphQLID,
             GraphQLInt, GraphQLString, ${enumImports.join(', ')} } from '../..';
    @InputType()
    export class ${entity.name}UpdateManyDataInput {
      ${fieldTemplates}
    }
  `;
}
exports.entityToUpdateDataInput = entityToUpdateDataInput;
function entityToUpdateManyWithWhereNestedInput(entity) {
    return `
    import 'reflect-metadata';
    import { InputType, Field as FieldGraphQL } from 'type-graphql'
    import { ${entity.name}UpdateManyDataInput,
             ${entity.name}ScalarWhereInput } from '../..';
    @InputType()
    export class ${entity.name}UpdateManyWithWhereNestedInput {
      @FieldGraphQL(() => ${entity.name}UpdateManyDataInput)
      data!: ${entity.name}UpdateManyDataInput
      @FieldGraphQL(() => ${entity.name}ScalarWhereInput)
      where!: ${entity.name}ScalarWhereInput
    }
  `;
}
exports.entityToUpdateManyWithWhereNestedInput = entityToUpdateManyWithWhereNestedInput;
function entityToUpdateInputs(entity) {
    const updateInputs = {};
    entity.relations.forEach((relation) => {
        const { graphqlType } = utils_1.relationToTypes(relation);
        if (!relation.inverseEntityMetadata || graphqlType.constructor !== graphql_1.GraphQLObjectType)
            return;
        const { inverseSidePropertyPath } = relation;
        const isInverse = !!relation.inverseEntityMetadata.relations.find(inverseRelation => inverseRelation.propertyName === inverseSidePropertyPath);
        const inverseSidePropertyPathCapitalized = inverseSidePropertyPath.charAt(0).toUpperCase() + inverseSidePropertyPath.slice(1);
        const _createInputName = (prefix) => `${graphqlType.name}Create${prefix}${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`;
        const _updateInputName = (prefix) => `${graphqlType.name}Update${prefix}${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`;
        const _updateInputNameWithWhere = (prefix, postfix) => `${graphqlType.name}Update${prefix}WithWhere${postfix}${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`;
        const _updateInputNameWithWhereNested = (prefix, postfix) => `${graphqlType.name}Update${prefix}WithWhere${postfix}Input`;
        const getFields = () => ({
            fields: relation.inverseEntityMetadata.columns
                .filter((column) => !(column.relationMetadata || column.propertyName === inverseSidePropertyPath) &&
                !column.isPrimary &&
                !column.isCreateDate &&
                !column.isGenerated &&
                !column.isUpdateDate &&
                !column.isVersion)
                .map((column) => {
                const graphQLDataType = utils_1.columnTypeToGraphQLDataType(column);
                const nullable = '{ nullable: true }';
                const tsRequired = '?';
                const tsType = utils_1.columnToTypeScriptType(column);
                return `
            @FieldGraphQL(() => ${graphQLDataType}, ${nullable})
            ${column.propertyName}${tsRequired}: ${tsType};
            `;
            })
                .join(''),
            enumImports: relation.inverseEntityMetadata.columns
                .filter((column) => !(column.relationMetadata || column.propertyName === inverseSidePropertyPath) &&
                !column.isPrimary &&
                !column.isCreateDate &&
                !column.isGenerated &&
                !column.isUpdateDate &&
                !column.isVersion &&
                column.enum)
                .reduce((prev, column) => {
                const tsType = utils_1.columnToTypeScriptType(column);
                if (!prev.includes(tsType)) {
                    prev = [...prev, tsType];
                }
                return prev;
            }, [])
        });
        const getRelationsWithImports = () => {
            const imports = [];
            const relations = relation.inverseEntityMetadata.relations
                .filter(inverseRelation => inverseRelation.propertyName !== inverseSidePropertyPath)
                .map(inverseRelation => {
                const { inverseGraphqlType } = utils_1.inverseRelationToTypes(inverseRelation);
                const nullable = '{nullable:true}';
                const tsRequired = '?';
                const propertyName = inverseRelation.propertyName;
                const inverseSidePropertyPath = inverseRelation.inverseSidePropertyPath;
                const isInverse = Boolean(inverseRelation.inverseEntityMetadata.relations.find(inverseInverseRelation => inverseInverseRelation.propertyName === inverseSidePropertyPath));
                const inverseSidePropertyPathCapitalized = inverseSidePropertyPath.charAt(0).toUpperCase() + inverseSidePropertyPath.slice(1);
                if (inverseGraphqlType.constructor === graphql_1.GraphQLObjectType) {
                    switch (inverseRelation.relationType) {
                        case 'many-to-one':
                        case 'one-to-one':
                            if (!imports.includes(`${inverseGraphqlType.name}UpdateOne${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`)) {
                                imports.push(`${inverseGraphqlType.name}UpdateOne${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`);
                            }
                            return `
              @FieldGraphQL(() => ${inverseGraphqlType.name}UpdateOne${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input,${nullable})
              ${propertyName}${tsRequired}: ${inverseGraphqlType.name}UpdateOne${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input;
              `;
                        case 'one-to-many':
                        case 'many-to-many':
                            if (!imports.includes(`${inverseGraphqlType.name}UpdateMany${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`)) {
                                imports.push(`${inverseGraphqlType.name}UpdateMany${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input`);
                            }
                            return `
              @FieldGraphQL(() => ${inverseGraphqlType.name}UpdateMany${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input,${nullable})
              ${propertyName}${tsRequired}: ${inverseGraphqlType.name}UpdateMany${isInverse ? 'Without' + inverseSidePropertyPathCapitalized : ''}Input;
              `;
                    }
                }
                return '';
            });
            return { relations, imports };
        };
        const createInputName = _createInputName('');
        // const _createInputOneName = _createInputName('One');
        // const createInputManyName = _createInputName('Many');
        const updateInputName = _updateInputName('');
        const updateInputNameUnique = _updateInputNameWithWhere('', 'Unique');
        const updateInputNameNested = _updateInputNameWithWhereNested('Many', 'Nested');
        const updateInputOneName = _updateInputName('One');
        const updateInputManyName = _updateInputName('Many');
        switch (relation.relationType) {
            case 'many-to-one':
            case 'one-to-one':
                if (!Object.keys(updateInputs).includes(updateInputName)) {
                    updateInputs[updateInputName] = {
                        ...getFields(),
                        ...getRelationsWithImports()
                    };
                }
                if (!Object.keys(updateInputs).includes(updateInputOneName)) {
                    updateInputs[updateInputOneName] = {
                        fields: `
              @FieldGraphQL(() => ${graphqlType.name}WhereUniqueInput,{nullable:true})
              connect?: ${graphqlType.name}WhereUniqueInput;
              @FieldGraphQL(() => ${createInputName},{nullable:true})
              create?: ${createInputName}
              @FieldGraphQL(() => Boolean,{nullable:true})
              delete: boolean
              @FieldGraphQL(() => Boolean,{nullable:true})
              disconnect: boolean
              @FieldGraphQL(() => ${updateInputName},{nullable:true})
              update: ${updateInputName}
              `,
                        imports: [`${graphqlType.name}WhereUniqueInput`, createInputName, updateInputName]
                    };
                }
                break;
            case 'one-to-many':
            case 'many-to-many':
                if (!Object.keys(updateInputs).includes(updateInputName)) {
                    updateInputs[updateInputName] = {
                        ...getFields(),
                        ...getRelationsWithImports()
                    };
                }
                if (!Object.keys(updateInputs).includes(updateInputNameUnique)) {
                    updateInputs[updateInputNameUnique] = {
                        fields: `
          @FieldGraphQL(() => ${updateInputName})
          data!: ${updateInputName}
          @FieldGraphQL(() => ${graphqlType.name}WhereUniqueInput)
          where!: ${graphqlType.name}WhereUniqueInput
          `,
                        imports: [updateInputName, `${graphqlType.name}WhereUniqueInput`]
                    };
                }
                if (!Object.keys(updateInputs).includes(updateInputManyName)) {
                    updateInputs[updateInputManyName] = {
                        fields: `
              @FieldGraphQL(() => [${graphqlType.name}WhereUniqueInput],{nullable:true})
              connect?: ${graphqlType.name}WhereUniqueInput[];
              @FieldGraphQL(() => [${createInputName}],{nullable:true})
              create?: ${createInputName}[];
              @FieldGraphQL(() => [${graphqlType.name}WhereUniqueInput],{nullable:true})
              delete?: ${graphqlType.name}WhereUniqueInput[];
              @FieldGraphQL(() => [${graphqlType.name}WhereInput],{nullable:true})
              deleteMany?: [${graphqlType.name}WhereInput];
              @FieldGraphQL(() => [${graphqlType.name}WhereUniqueInput],{nullable:true})
              disconnect?: ${graphqlType.name}WhereUniqueInput[];
              @FieldGraphQL(() => [${graphqlType.name}WhereUniqueInput],{nullable:true})
              set?: ${graphqlType.name}WhereUniqueInput[];
              @FieldGraphQL(() => ${updateInputNameUnique},{nullable:true})
              update?: ${updateInputNameUnique};
              @FieldGraphQL(() => [${updateInputNameNested}],{nullable:true})
              updateMany?: ${updateInputNameNested}[];
              `,
                        imports: [
                            `${graphqlType.name}WhereUniqueInput`,
                            `${graphqlType.name}WhereInput`,
                            createInputName,
                            updateInputName,
                            updateInputNameUnique,
                            updateInputNameNested
                        ]
                    };
                }
                break;
        }
    });
    return Object.keys(updateInputs).reduce((prev, updateInput) => {
        return {
            ...prev,
            [updateInput]: `
        import 'reflect-metadata';
        import { ArgsType, Field as FieldGraphQL, Float, GraphQLISODateTime,
               ID, InputType,
               ObjectType, registerEnumType } from 'type-graphql';
        import { GraphQLJSONObject,
                 IDType, ConnectionArgs, PageInfo,
                 GraphQLBoolean, GraphQLFloat, GraphQLID,
                 GraphQLInt, GraphQLString, ${(updateInputs[updateInput].enumImports || []).join(', ')} } from '../..';
        ${updateInputs[updateInput].imports.length
                ? `
        import { ${updateInputs[updateInput].imports.join(', ')} } from '../..';
        `
                : ''}
        @InputType()
        export class ${updateInput} {
        ${updateInputs[updateInput].fields}
        ${(updateInputs[updateInput].relations || []).join('')}
      }
      `
        };
    }, {});
}
exports.entityToUpdateInputs = entityToUpdateInputs;
function entityToUpdateInputArgs(entity) {
    return `
    @ArgsType()
    export class ${entity.name}UpdateArgs {
      @FieldGraphQL() data!: ${entity.name}UpdateInput;
      @FieldGraphQL() where!: ${entity.name}WhereUniqueInput;
    }
  `;
}
exports.entityToUpdateInputArgs = entityToUpdateInputArgs;
