"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const dataloader_1 = __importDefault(require("dataloader"));
const metadata_1 = require("../metadata");
const filter_1 = require("../sorm/filter");
const graphql_fields_1 = __importDefault(require("graphql-fields"));
class DataLoaderResolver {
    constructor(connection, relation) {
        this.connection = connection;
        this.relation = relation;
    }
    filter(args, fields) {
        return new dataloader_1.default((entities) => {
            if (Array.isArray(entities) && entities[0] && Array.isArray(entities[0])) {
                throw new Error('You must flatten arrays of arrays of entities');
            }
            let isBackward = false;
            let query = this.connection.createQueryBuilder().from(this.relation.type, this.relation.propertyName);
            const pk = metadata_1.getMetadataStorage().getPk(this.relation.inverseEntityMetadata.targetName) ||
                (() => {
                    for (const column of this.relation.inverseEntityMetadata.primaryColumns) {
                        if (column.target === this.relation.inverseEntityMetadata.target ||
                            typeof column.target !== 'function') {
                            continue;
                        }
                        const pk = metadata_1.getMetadataStorage().getPk(column.target.name);
                        if (pk) {
                            return pk;
                        }
                    }
                    return undefined;
                })();
            if (!pk) {
                throw new Error(`${this.relation.inverseEntityMetadata.targetName} must have decorator Id for Model.`);
            }
            if (Object.keys(args).length) {
                const isMany = this.relation.isOneToMany || this.relation.isManyToMany;
                filter_1.filterQuery(this.relation.inverseEntityMetadata.target, args, query);
                if (isMany) {
                    isBackward = Boolean(filter_1.getCursor(this.relation.inverseEntityMetadata.target, query, args, pk).isBackward);
                }
            }
            if (fields && fields.length) {
                fields = (fields || []).filter(field => this.relation.inverseEntityMetadata.columns.some(column => column.propertyName === field));
                if (!fields.includes(pk)) {
                    fields.push(pk);
                }
                query.select(fields.map(field => `${query.alias}.${field}`));
            }
            return this.connection.relationIdLoader
                .loadManyToManyRelationIdsAndGroup(this.relation, entities, undefined, query)
                .then(groups => {
                if (isBackward) {
                    return groups.map(group => group.related).reverse();
                }
                else {
                    return groups.map(group => group.related);
                }
            });
        });
    }
    filterAndConnection(args, info) {
        return new dataloader_1.default(async (entitiesParent) => {
            if (Array.isArray(entitiesParent) && entitiesParent[0] && Array.isArray(entitiesParent[0])) {
                throw new Error('You must flatten arrays of arrays of entities');
            }
            let startCursor, endCursor, hasNextPage = false, hasPreviousPage = false;
            // const isMany=this.relation.isOneToMany||this.relation.isManyToMany;
            const pk = metadata_1.getMetadataStorage().getPk(this.relation.inverseEntityMetadata.targetName) ||
                (() => {
                    for (const column of this.relation.inverseEntityMetadata.primaryColumns) {
                        if (column.target === this.relation.inverseEntityMetadata.target ||
                            typeof column.target !== 'function') {
                            continue;
                        }
                        const pk = metadata_1.getMetadataStorage().getPk(column.target.name);
                        if (pk) {
                            return pk;
                        }
                    }
                    return undefined;
                })();
            if (!pk) {
                throw new Error(`${this.relation.inverseEntityMetadata.targetName} must have decorator Id for Model.`);
            }
            const query = this.connection.createQueryBuilder().from(this.relation.type, Object.prototype.hasOwnProperty.call(this.relation.type, 'name') ? this.relation.type.name : this.relation.propertyName);
            filter_1.filterQuery(this.relation.inverseEntityMetadata.target, args, query);
            const rawFields = graphql_fields_1.default(info);
            const rawFieldsNode = ('edges' in rawFields && 'node' in rawFields.edges && rawFields.edges.node) || {};
            const fields = Object.keys(rawFieldsNode).filter(item => {
                return (Object.keys(rawFieldsNode[item]).length === 0 &&
                    this.relation.inverseEntityMetadata.columns.some(column => column.propertyName === item));
            });
            if (!fields.includes(pk)) {
                fields.push(pk);
            }
            query.select(fields.map(field => `${query.alias}.${field}`));
            const { isBackward, slice } = filter_1.getCursor(this.relation.inverseEntityMetadata.target, query, args, pk, true);
            return this.connection.relationIdLoader
                .loadManyToManyRelationIdsAndGroup(this.relation, entitiesParent, undefined, query)
                .then(groups => {
                return groups.map(group => {
                    const entitiesGroup = group.related;
                    if (!Array.isArray(entitiesGroup))
                        return entitiesGroup;
                    const edges = isBackward
                        ? (entitiesGroup || []).slice(0, slice || undefined).reverse()
                        : (entitiesGroup || []).slice(0, slice || undefined);
                    const count = edges.length;
                    if (count) {
                        startCursor = edges[0][pk];
                        endCursor = edges[count - 1][pk];
                        hasNextPage = (!isBackward && entitiesGroup.length > count) || false;
                        hasPreviousPage = (isBackward && entitiesGroup.length > count) || false;
                    }
                    return {
                        edges: (edges => edges.map((node) => ({
                            cursor: node[pk],
                            node
                        })))(edges),
                        pageInfo: {
                            hasNextPage,
                            hasPreviousPage,
                            startCursor,
                            endCursor
                        },
                        aggregate: {
                            count
                        }
                    };
                });
            });
        });
    }
    simple(fields) {
        return new dataloader_1.default((entities) => {
            if (Array.isArray(entities) && entities[0] && Array.isArray(entities[0])) {
                throw new Error('You must flatten arrays of arrays of entities');
            }
            let query = undefined;
            if (fields && fields.length) {
                query = this.connection.createQueryBuilder().from(this.relation.type, this.relation.propertyName);
                const pk = metadata_1.getMetadataStorage().getPk(this.relation.inverseEntityMetadata.targetName) ||
                    (() => {
                        for (const column of this.relation.inverseEntityMetadata.primaryColumns) {
                            if (column.target === this.relation.inverseEntityMetadata.target ||
                                typeof column.target !== 'function') {
                                continue;
                            }
                            const pk = metadata_1.getMetadataStorage().getPk(column.target.name);
                            if (pk) {
                                return pk;
                            }
                        }
                        return undefined;
                    })();
                if (!pk) {
                    throw new Error(`${this.relation.inverseEntityMetadata.targetName} must have decorator Id for Model.`);
                }
                fields = (fields || []).filter(field => this.relation.inverseEntityMetadata.columns.some(column => column.propertyName === field));
                if (!fields.includes(pk)) {
                    fields.push(pk);
                }
                query.select(fields.map(field => `${query.alias}.${field}`));
            }
            return this.connection.relationIdLoader
                .loadManyToManyRelationIdsAndGroup(this.relation, entities, undefined, query)
                .then(groups => groups.map(group => group.related));
        });
    }
}
exports.DataLoaderResolver = DataLoaderResolver;
