"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typeorm_1 = require("typeorm");
const orderBy_1 = require("../orderBy");
const getCursor = (entity, query, args, pk, connection) => {
    const first = Math.max(Number(args.first || 0), 0);
    const last = Math.max(Number(args.last || 0), 0);
    const skip = Math.max(Number(args.skip || 0), 0);
    if (first && last) {
        throw new Error(`
      Including a value for both first and last is not supported.
      See the spec for a discussion of why
      https://facebook.github.io/relay/graphql/connections.htm#sec-Pagination-algorithm`);
    }
    const limit = (() => {
        if (connection === true) {
            if (first) {
                return first + 1;
            }
            else if (last) {
                return last + 1;
            }
            return 0;
        }
        else {
            if (first) {
                return first;
            }
            else if (last) {
                return last;
            }
            return 0;
        }
    })();
    query.limit(limit);
    if (args.before) {
        if (Array.isArray(args.orderBy) && args.orderBy.length) {
            if (args.orderBy.length > 1)
                throw new Error('cursor orderBy error');
            const parts = args.orderBy[0].split('_');
            if (!parts.length)
                throw new Error('cursor orderBy error');
            const attr = parts[0];
            const operator = parts[1] === 'DESC' ? parts[1] : 'ASC';
            if (operator === 'DESC') {
                query.andWhere(new typeorm_1.Brackets(wb => {
                    wb.andWhere(`"${query.alias}"."${attr}" = ${query.subQuery()
                        .select([`"${query.alias}"."${attr}"`])
                        .from(entity, query.alias)
                        .where(`"${query.alias}"."${pk}" = '${args.before}'`)
                        .getQuery()} and "${query.alias}"."${pk}" < '${args.before}'`);
                    wb.orWhere(`"${query.alias}"."${attr}" > ${query.subQuery()
                        .select([`"${query.alias}"."${attr}"`])
                        .from(entity, query.alias)
                        .where(`"${query.alias}"."${pk}" = '${args.before}'`)
                        .getQuery()}`);
                }));
            }
            else {
                query.andWhere(new typeorm_1.Brackets(wb => {
                    wb.andWhere(`"${query.alias}"."${attr}" = ${query.subQuery()
                        .select([`"${query.alias}"."${attr}"`])
                        .from(entity, query.alias)
                        .where(`"${query.alias}"."${pk}" = '${args.before}'`)
                        .getQuery()} and "${query.alias}"."${pk}" < '${args.before}'`);
                    wb.orWhere(`"${query.alias}"."${attr}" < ${query.subQuery()
                        .select([`"${query.alias}"."${attr}"`])
                        .from(entity, query.alias)
                        .where(`"${query.alias}"."${pk}" = '${args.before}'`)
                        .getQuery()}`);
                }));
            }
        }
        else {
            query.andWhere(`"${query.alias}"."${pk}" < '${args.before}'`);
        }
    }
    if (args.after) {
        if (Array.isArray(args.orderBy) && args.orderBy.length) {
            if (args.orderBy.length > 1)
                throw new Error('cursor orderBy error');
            const parts = args.orderBy[0].split('_');
            if (!parts.length)
                throw new Error('cursor orderBy error');
            const attr = parts[0];
            const operator = parts[1] === 'DESC' ? parts[1] : 'ASC';
            if (operator === 'DESC') {
                query.andWhere(new typeorm_1.Brackets(wb => {
                    wb.andWhere(`"${query.alias}"."${attr}" < ${query.subQuery()
                        .select([`"${query.alias}"."${attr}"`])
                        .from(entity, query.alias)
                        .where(`"${query.alias}"."${pk}" = '${args.after}'`)
                        .getQuery()} and "${query.alias}"."${pk}" = '${args.after}'`);
                    wb.orWhere(`"${query.alias}"."${attr}" < ${query.subQuery()
                        .select([`"${query.alias}"."${attr}"`])
                        .from(entity, query.alias)
                        .where(`"${query.alias}"."${pk}" = '${args.after}'`)
                        .getQuery()}`);
                }));
            }
            else {
                query.andWhere(new typeorm_1.Brackets(wb => {
                    wb.andWhere(`"${query.alias}"."${attr}" > ${query.subQuery()
                        .select([`"${query.alias}"."${attr}"`])
                        .from(entity, query.alias)
                        .where(`"${query.alias}"."${pk}" = '${args.after}'`)
                        .getQuery()} and "${query.alias}"."${pk}" = '${args.after}'`);
                    wb.orWhere(`"${query.alias}"."${attr}" > ${query.subQuery()
                        .select([`"${query.alias}"."${attr}"`])
                        .from(entity, query.alias)
                        .where(`"${query.alias}"."${pk}" = '${args.after}'`)
                        .getQuery()}`);
                }));
            }
            /*console.log(query.alias);
            console.log(query.subQuery()
              .select([attr])
              .from(entity,query.alias)
              .where(`"${query.alias}"."${pk}" = '${args.after}'`)
              .getQuery())*/
        }
        else {
            query.andWhere(`"${query.alias}"."${pk}" > '${args.after}'`);
        }
    }
    query = orderBy_1.orderBy(query, args, Boolean(last));
    query.addOrderBy(`"${query.alias}"."${pk}"`, (!last && 'ASC') || 'DESC');
    query.offset(skip);
    return { slice: limit ? limit - (connection ? 1 : 0) : 0, isBackward: Boolean(last) };
};
exports.default = getCursor;
