"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typeorm_1 = require("typeorm");
exports.getFindOperator = (key, value) => {
    const match = key.toString().match(/^(?<attr>[a-zA-Z]+)((_(?<operator>[a-zA-Z_]+))|)$/);
    if (!match || !match.groups) {
        throw new Error(`Can't find operator Regex error`);
    }
    const { attr, operator } = match.groups;
    switch (operator) {
        case undefined:
            if (value === null) {
                return [attr, typeorm_1.IsNull()];
            }
            return [attr, typeorm_1.Equal(value)];
        case 'not':
            return [attr, typeorm_1.Not(value)];
        case 'lt':
            return [attr, typeorm_1.LessThan(value)];
        case 'lte':
            return [attr, typeorm_1.Not(typeorm_1.MoreThan(value))];
        case 'gt':
            return [attr, typeorm_1.MoreThan(value)];
        case 'gte':
            return [attr, typeorm_1.Not(typeorm_1.LessThan(value))];
        case 'in':
            return [attr, typeorm_1.In(value)];
        case 'not_in':
            return [attr, typeorm_1.Not(typeorm_1.In(value))];
        case 'contains':
            return [attr, typeorm_1.Raw(alias => `LOWER(${alias}) LIKE LOWER('%${value}%')`)];
        case 'not_contains':
            return [attr, typeorm_1.Raw(alias => `LOWER(${alias}) NOT LIKE LOWER('%${value}%')`)];
        case 'starts_with':
            return [attr, typeorm_1.Raw(alias => `LOWER(${alias}) LIKE LOWER('${value}%')`)];
        case 'not_starts_with':
            return [attr, typeorm_1.Raw(alias => `LOWER(${alias}) NOT LIKE LOWER('${value}%')`)];
        case 'ends_with':
            return [attr, typeorm_1.Raw(alias => `LOWER(${alias}) LIKE LOWER('%${value}')`)];
        case 'not_ends_with':
            return [attr, typeorm_1.Raw(alias => `LOWER(${alias}) LIKE LOWER('%${value}')`)];
        default:
            throw new Error(`Can't find operator ${operator}`);
    }
};
